@@ -1,4 +1,9 @@
-# This program evaluates the values of a quadratic function.
+"""This program evaluates the values of a quadratic function.
+This is my first program on my journey. If anyone reads this, I have some
+questions, such as how can I write in an option to return answers in fractions.
+Where decimal answers are useful, fraction answers can be useful in other
+areas. Also, any tips would be wonderful. My email is nzashadow@gmail.com
+for suggestions"""
 
 print ("y = ax^2 + bx + c")
 
